==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/INTEGRATEDPLANNINGITEMID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INTEGRATEDPLANNINGITEMID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INTEGRATEDPLANNINGITEMID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTEGRATEDPLANNINGITEMCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTEGRATEDPLANNINGITEMDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INTEGRATEDPLANNINGITEMID_Type", propOrder = {
    "integratedplanningitemcode",
    "integratedplanningitemdescription"
})
public class INTEGRATEDPLANNINGITEMID_Type {

    @XmlElement(name = "INTEGRATEDPLANNINGITEMCODE", required = true)
    protected String integratedplanningitemcode;
    @XmlElement(name = "INTEGRATEDPLANNINGITEMDESCRIPTION")
    protected String integratedplanningitemdescription;

    /**
     * Gets the value of the integratedplanningitemcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINTEGRATEDPLANNINGITEMCODE() {
        return integratedplanningitemcode;
    }

    /**
     * Sets the value of the integratedplanningitemcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINTEGRATEDPLANNINGITEMCODE(String value) {
        this.integratedplanningitemcode = value;
    }

    /**
     * Gets the value of the integratedplanningitemdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINTEGRATEDPLANNINGITEMDESCRIPTION() {
        return integratedplanningitemdescription;
    }

    /**
     * Sets the value of the integratedplanningitemdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINTEGRATEDPLANNINGITEMDESCRIPTION(String value) {
        this.integratedplanningitemdescription = value;
    }

}

==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_fields/INTEGRATEDPLANNINGITEMID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour INTEGRATEDPLANNINGITEMID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INTEGRATEDPLANNINGITEMID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTEGRATEDPLANNINGITEMCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTEGRATEDPLANNINGITEMDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INTEGRATEDPLANNINGITEMID_Type", propOrder = {
    "integratedplanningitemcode",
    "integratedplanningitemdescription"
})
public class INTEGRATEDPLANNINGITEMID_Type {

    @XmlElement(name = "INTEGRATEDPLANNINGITEMCODE", required = true)
    protected String integratedplanningitemcode;
    @XmlElement(name = "INTEGRATEDPLANNINGITEMDESCRIPTION")
    protected String integratedplanningitemdescription;

    /**
     * Obtient la valeur de la propriété integratedplanningitemcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINTEGRATEDPLANNINGITEMCODE() {
        return integratedplanningitemcode;
    }

    /**
     * Définit la valeur de la propriété integratedplanningitemcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINTEGRATEDPLANNINGITEMCODE(String value) {
        this.integratedplanningitemcode = value;
    }

    /**
     * Obtient la valeur de la propriété integratedplanningitemdescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINTEGRATEDPLANNINGITEMDESCRIPTION() {
        return integratedplanningitemdescription;
    }

    /**
     * Définit la valeur de la propriété integratedplanningitemdescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINTEGRATEDPLANNINGITEMDESCRIPTION(String value) {
        this.integratedplanningitemdescription = value;
    }

}
